==> kite-1.0b3.tar.gz: kite-1.0b3/regex/microregex.h <==
/*****************************************************************************
 * Copyright (c) 2008, Mooneer Salem
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Kite Language organization nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
#ifndef MICROREGEX_H
#define MICROREGEX_H

/****************************************************************************
 * These types should not be internally accessable by users.
 ****************************************************************************/
#ifndef __MICROREGEX_INTERNAL
typedef void* microregex_t;
typedef void* microregex_nfa_t; 
typedef void* microregex_state_t;
#else
struct microregex_t;
struct microregex_nfa_t;
struct microregex_state_t;
typedef struct microregex_t* microregex_t;
typedef struct microregex_nfa_t* microregex_nfa_t;
typedef struct microregex_state_t* microregex_state_t;
#endif /* __MICROREGEX_INTERNAL */

/****************************************************************************
 * Regular expression creation/destruction
 ****************************************************************************/
 
/**
 * Create regular expression object.
 * @param regex The regular expression to parse.
 * @return The created regular expression object.
 */
microregex_t microregex_create(char *regex);

/**
 * Destroy regular expression object.
 * @param regex_obj The regular expression object to destroy.
 */
void microregex_destroy(microregex_t *regex_obj);

/****************************************************************************
 * Regular expression matching options
 ****************************************************************************/
 
/**
 * Set case insensitivity of regular expression.
 * @param regex_obj The regular expression object to edit.
 * @param val Value to set flag to.
 */
void microregex_set_case_insensitivity(microregex_t regex_obj, int val);

/****************************************************************************
 * Regular expression matching
 ****************************************************************************/
 
/**
 * Destroys state object.
 * @param st Pointer to state object to destroy.
 */
void microregex_state_destroy(microregex_state_t *st);

/**
 * Match text based on given regex.
 * @param regex_obj The regular expression object to use.
 * @param str The string in which to find the given regex.
 * @param start Starting index inside string
 * @return A match object with specified match info.
 */
microregex_state_t 
microregex_match(microregex_t regex_obj, char *str, int start);

/**
 * Get the number of substrings captured by parenthesis.                                               
 * @param st The state object to use.                                                                  
 * @return The number of subexpressions captured by this match.                                        
 */
int microregex_state_get_num_captured(microregex_state_t st);

/**
 * Get the location of the match                                              
 * @param st The state object to use.                                                                  
 * @return The location of the match.
 */
int microregex_state_get_match_begin(microregex_state_t st);

/**                                                                                                    
 * Get the substring captured by parenthesis                                                           
 * @param st The state object to use.                                                                  
 * @param n The subexpression number (0 = entire match)                                                
 * @return The string captured by the subexpression.                                                   
 */
char *microregex_state_get_subexpression(microregex_state_t st, int n);

#endif /* MICROREGEX_H */

==> kite_1.0.2.orig.tar.gz: kite-1.0.2/regex/microregex.h <==
/*****************************************************************************
 * Copyright (c) 2008, Mooneer Salem
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Kite Language organization nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
#ifndef MICROREGEX_H
#define MICROREGEX_H

/****************************************************************************
 * These types should not be internally accessable by users.
 ****************************************************************************/
#ifndef __MICROREGEX_INTERNAL
typedef void* microregex_t;
typedef void* microregex_nfa_t; 
typedef void* microregex_state_t;
#else
struct microregex_t;
struct microregex_nfa_t;
struct microregex_state_t;
typedef struct microregex_t* microregex_t;
typedef struct microregex_nfa_t* microregex_nfa_t;
typedef struct microregex_state_t* microregex_state_t;
#endif /* __MICROREGEX_INTERNAL */

/****************************************************************************
 * Regular expression creation/destruction
 ****************************************************************************/
 
/**
 * Create regular expression object.
 * @param regex The regular expression to parse.
 * @return The created regular expression object.
 */
microregex_t microregex_create(const char *regex);

/**
 * Destroy regular expression object.
 * @param regex_obj The regular expression object to destroy.
 */
void microregex_destroy(microregex_t *regex_obj);

/****************************************************************************
 * Regular expression matching options
 ****************************************************************************/
 
/**
 * Set case insensitivity of regular expression.
 * @param regex_obj The regular expression object to edit.
 * @param val Value to set flag to.
 */
void microregex_set_case_insensitivity(microregex_t regex_obj, int val);

/****************************************************************************
 * Regular expression matching
 ****************************************************************************/
 
/**
 * Destroys state object.
 * @param st Pointer to state object to destroy.
 */
void microregex_state_destroy(microregex_state_t *st);

/**
 * Match text based on given regex.
 * @param regex_obj The regular expression object to use.
 * @param str The string in which to find the given regex.
 * @param start Starting index inside string
 * @return A match object with specified match info.
 */
microregex_state_t 
microregex_match(microregex_t regex_obj, const char *str, int start);

/**
 * Get the number of substrings captured by parenthesis.                                               
 * @param st The state object to use.                                                                  
 * @return The number of subexpressions captured by this match.                                        
 */
int microregex_state_get_num_captured(microregex_state_t st);

/**
 * Get the location of the match                                              
 * @param st The state object to use.                                                                  
 * @return The location of the match.
 */
int microregex_state_get_match_begin(microregex_state_t st);

/**                                                                                                    
 * Get the substring captured by parenthesis                                                           
 * @param st The state object to use.                                                                  
 * @param n The subexpression number (0 = entire match)                                                
 * @return The string captured by the subexpression.                                                   
 */
char *microregex_state_get_subexpression(microregex_state_t st, int n);

#endif /* MICROREGEX_H */
